'use strict';

var constants = require('./constants.js');

function formatErrorMessage(message, client = constants.CLIENT) {
    return message.startsWith(`${client}`) ? message : `${client}: ${message}`;
}
function getErrorMessage(error) {
    return error instanceof Error ? error.message : JSON.stringify(error);
}
function validateRetries({ client, retries, }) {
    if (retries !== undefined &&
        (typeof retries !== "number" ||
            retries < constants.MIN_RETRIES ||
            retries > constants.MAX_RETRIES)) {
        throw new Error(`${client}: The provided "retries" value (${retries}) is invalid - it cannot be less than ${constants.MIN_RETRIES} or greater than ${constants.MAX_RETRIES}`);
    }
}
function getKeyValueIfValid(key, value) {
    return value &&
        (typeof value !== "object" ||
            Array.isArray(value) ||
            (typeof value === "object" && Object.keys(value).length > 0))
        ? { [key]: value }
        : {};
}

exports.formatErrorMessage = formatErrorMessage;
exports.getErrorMessage = getErrorMessage;
exports.getKeyValueIfValid = getKeyValueIfValid;
exports.validateRetries = validateRetries;
//# sourceMappingURL=utilities.js.map
